@@ -25,6 +25,9 @@ public:
 protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+
+private:
+    void onManageVirtualConnectionsChanged();
 };
 
 #endif // PLASMA_NM_APPLET_PROXY_MODEL_H
